@@ -28,6 +28,8 @@
 # POSSIBILITY OF SUCH DAMAGE.
 ###
 
+from __future__ import print_function
+
 from supybot.test import *
 
 class MathTestCase(PluginTestCase):
@@ -99,7 +101,7 @@ class MathTestCase(PluginTestCase):
         self.assertResponse('calc 5*0.06', str(5*0.06))
         self.assertResponse('calc 2.0-7.0', str(2-7))
         self.assertResponse('calc e**(i*pi)+1', '0')
-        if sys.version_info[0] >= 3:
+        if minisix.PY3:
             # Python 2 has bad handling of exponentiation of negative numbers
             self.assertResponse('calc (-1)**.5', 'i')
             self.assertRegexp('calc (-5)**.5', '2.236067977[0-9]+i')
@@ -112,7 +114,7 @@ class MathTestCase(PluginTestCase):
         self.assertNotError('calc (1600 * 1200) - 2*(1024*1280)')
         self.assertNotError('calc 3-2*4')
         self.assertNotError('calc (1600 * 1200)-2*(1024*1280)')
-        self.assertError('calc factorial(99)')
+        self.assertError('calc factorial(20000)')
 
     def testCalcNoNameError(self):
         self.assertNotRegexp('calc foobar(x)', 'NameError')
@@ -137,7 +139,7 @@ class MathTestCase(PluginTestCase):
         self.assertResponse('icalc 1^1', '0')
         self.assertResponse('icalc 10**24', '1' + '0'*24)
         self.assertRegexp('icalc 49/6', '8.16')
-        self.assertNotError('icalc factorial(99)')
+        self.assertNotError('icalc factorial(20000)')
 
     def testRpn(self):
         self.assertResponse('rpn 5 2 +', '7')
