@@ -47,8 +47,10 @@ class Author(object):
         self.email = email
 
     def __str__(self):
-        return '%s (%s) <%s>' % (self.name, self.nick,
-                                 utils.web.mungeEmail(self.email))
+        if self.name != self.nick:
+            return '%s (%s) <%s>' % (self.name, self.nick, self.email)
+        else:
+            return '%s <%s>' % (self.name, self.email)
 
 class authors(object): # This is basically a bag.
     jemfinch = Author('Jeremy Fincher', 'jemfinch', 'jemfinch@users.sf.net')
@@ -62,7 +64,8 @@ class authors(object): # This is basically a bag.
     grantbow = Author('Grant Bowman', 'Grantbow', 'grantbow@grantbow.com')
     stepnem = Author('Štěpán Němec', 'stepnem', 'stepnem@gmail.com')
     progval = Author('Valentin Lorentz', 'ProgVal', 'progval@gmail.com')
-    unknown = Author('Unknown author', 'unknown', 'unknown@supybot.org')
+    jlu = Author('James Lu', 'GLolol', 'james@overdrivenetworks.com')
+    unknown = Author('Unknown author', 'unknown', 'unknown@email.invalid')
 
     # Let's be somewhat safe about this.
     def __getattr__(self, attr):
